@@ -4,15 +4,15 @@ from __future__ import absolute_import, unicode_literals
 import gc
 import os
 
-dll_path = os.path.join(os.path.dirname(__file__), 'dlls')
-if dll_path not in os.environ['PATH']:
-  os.environ['PATH'] += '%s;' % os.path.join(os.path.dirname(__file__), 'dlls')
+resources_path = os.path.join(os.path.dirname(__file__), 'resources')
+if resources_path not in os.environ['PATH']:
+	os.environ['PATH'] += '%s;' % resources_path
 
 from . import core
 
 show_default_optimize_code_points = core.show_default_optimize_code_points
 
-__version__ = '0.6.5'
+__version__ = '0.7.0'
 __doc__ = """
 VFB2UFO3
 DESCRIPTION
@@ -30,42 +30,48 @@ ignored. A batch command can be created for use with `psautohint`, which
 supports hinting outlines with decimal coordinates.
 
 INSTALLATION
-This package may be installed via PyPi:
-
+PyPi
 `pip install vfb2ufo3`
 
-Alternatively, the latest release `.zip` may be downloaded, unzipped, and added
-to your FontLab Macros folder as shown:
+FontLab Installer
+Download the lastest release FontLab installer (`.flw`) file and drag it into
+the FontLab main window then restart FontLab or reset macro system.
+
+ZIP Archive
+Download and extract the latest release `.zip` file and move the extracted
+files to your FontLab Macros folder. The default directory structure is shown
+below.
 
 
 ```
 [user folder]
-  └── Documents
-      └── Fontlab
-          └── Studio 5
-              └── Macros
-                  └── System
-                      └── Modules
-                          └── vfb2ufo3
-                              ├── dlls
-                              │   ├── libgcc_s_dw2-1.dll
-                              │   ├── libgomp-1.dll
-                              │   ├── libstdc++-6.dll
-                              │   └── libwinpthread-1.dll
-                              ├── __init__.py
-                              ├── core.pyd
-                              ├── designspace.pyd
-                              ├── fdk.pyd
-                              ├── fea.pyd
-                              ├── fontinfo.pyd
-                              ├── glif.pyd
-                              ├── groups.pyd
-                              ├── kern.pyd
-                              ├── mark.pyd
-                              ├── plist.pyd
-                              ├── tools.pyd
-                              ├── user.py
-                              └── vfb.pyd
+    └── Documents
+        └── Fontlab
+            └── Studio 5
+                └── Macros
+                    └── System
+                        └── Modules
+                            └── vfb2ufo3
+                                ├── resources
+                                │   ├── libgcc_s_dw2-1.dll
+                                │   ├── libgomp-1.dll
+                                │   ├── libstdc++-6.dll
+                                │   ├── libwinpthread-1.dll
+                                │   └── zlib1.dll
+                                ├── __init__.py
+                                ├── core.pyd
+                                ├── designspace.pyd
+                                ├── fdk.pyd
+                                ├── fea.pyd
+                                ├── fontinfo.pyd
+                                ├── glif.pyd
+                                ├── groups.pyd
+                                ├── kern.pyd
+                                ├── mark.pyd
+                                ├── plist.pyd
+                                ├── tools.pyd
+                                ├── user.py
+                                └── vfb.pyd
 ```
 
 REQUIREMENTS
@@ -74,10 +80,8 @@ written in C++ and Cython. The submodules are compiled into `.pyd` extension
 modules. To recompile the submodules, the PyPi `cython` package and a compiler
 for Cython to utilize during extension module compilation will be required.
 
-The `glif.pyd` extension module requires DLLs from the MinGW 32-bit GCC:
-`libgcc_s_dw2-1.dll`, `libgomp-1.dll`, `libwinpthread-1.dll`, and
-`libstdc++-6.dll`. These DLLs are included in the release `.zip` archives and
-the PyPi package.
+The `glif.pyd` and `plist.pyd` extension modules require several DLLs included
+in the release `.zip` archive, FontLab installer, and PyPi package.
 
 OPTIONAL
   cython
@@ -88,8 +92,9 @@ OPTIONAL
   pip install afdko
   https://github.com/adobe-type-tools/afdko
 
-  MinGW 32-bit/i686 GCC 9.3.0
+  MinGW 32-bit/i686 GCC >= 9.3.0
   http://winlibs.com
+  https://www.msys2.org
   http://mingw.org
 
 FUNCTIONALITY
@@ -607,7 +612,7 @@ vfb2ufo3.write_ufo(
 	)
 ```
 
-Test (~3200 glyphs @ 10,000 UPM -> 1,000 UPM), ≈3-4 sec
+Test (~3200 glyphs @ 10,000 UPM -> 1,000 UPM), ≈3 sec
 
 ```
 flc_path = <path to .flc file>
@@ -617,6 +622,29 @@ vfb2ufo3.write_ufo(
 	)
 ```
 
+Test (~3200 glyphs @ 10,000 UPM -> 1,000 UPM), ≈1.5 sec
+
+```
+flc_path = <path to .flc file>
+
+vfb2ufo3.write_ufo(
+	groups_flc_path=flc_path,
+	ufoz=True,
+	)
+```
+
+Test (~3200 glyphs @ 10,000 UPM -> 1,000 UPM), <1.5 sec
+
+```
+flc_path = <path to .flc file>
+
+vfb2ufo3.write_ufo(
+	groups_flc_path=flc_path,
+	ufoz=True,
+	ufoz_compress=False,
+	)
+```
+
 Notes
 Generally, no assumptions are made about the correctness of the input. When
 `adfko_makeotf_release` mode is set, glyph name errors will raise an exception
@@ -628,10 +656,17 @@ Author
 Jameson R Spires
 
 License
-The GCC DLLs are covered under the GPL License; all other source is covered
-under the MIT License.
+Source files are covered under the MIT License.
 
 Version history
+version 0.7.0
+additional C++ conversion for `.ufoz` file creation utilizing zlib compression
+small changes and corrections
+
+version 0.6.6
+change to `setup.py` for PyPi package
+created FontLab installer
+
 version 0.6.5
 change to `glif.hpp`
 
